==> totvs-log-web-foundation-0.0.9.tgz: package/src/lib/services/intl/intl-literal-loader.service.ts <==
import { ILiteralsLoader } from 'totvs-log-base-foundation';
import { Observable } from 'rxjs';
import { map, mergeMap, catchError } from 'rxjs/operators';
import { ILiterals } from 'totvs-log-base-foundation';
import { HttpClient } from '@angular/common/http';
import { IWebI18nOptions } from './web-i18n-options.interface';
import { Injectable } from '@angular/core';
import { ThfI18nService } from '@totvs/thf-ui';

/**
 * Serviço que realiza o carregamento das literais do serviço de internacionalização
 */
@Injectable()
export class IntlLiteralsLoaderService implements ILiteralsLoader {

    /**
     * Atributo com opções de internacionalização Web
     */
    private webOptions: IWebI18nOptions = {context: '', language: '', url: ''};
    /**
     * Representa o cache da informação, em memória
     */
    private cache: any;

    /**
     * Método construtor da classe
     * @param http Parâmetro do serviço de Http
     * @param thfI18nService Parâmetro do serviço de internacionalização do THF
     */
    constructor(private http: HttpClient,
                private thfI18nService: ThfI18nService) {

    }

    /**
     * Método responsável por alterar as opções para carregamento de literais
     * @param options Parâmetro com as opções de internacionalização (url, language, context)
     */
    updateOptions(options: IWebI18nOptions): Observable<ILiterals> {
        const obs = new Observable<ILiterals>((observer) => {
            if ( this.optionsWasChanged(options) ) {
                Object.assign(this.webOptions, options);
                this.load().subscribe(x => {
                    this.cache = x;
                    observer.next(this.cache);
                });
            } else if (this.cache) {
                observer.next(this.cache);
            }
        });
        return obs;

    }


    /**
     * Método responsável por realizar o carregamento inicial das literais
     */
    load(): Observable<ILiterals> {
        return this.http.get<ILiterals>(this.webOptions.url)
        .pipe( map((res: ILiterals) => {
            const s = this.thfI18nService as any;
            s.config.contexts[this.webOptions.context] = res;
            s.setVarI18n(s.config.contexts);
            return res;
            }),
            mergeMap( (res) => this.updateLiteralsFromThfContext() ),
            catchError((e, caught) => caught)
        );

    }

    /**
     * Detecta se ocorreram mudanças na configuração
     */
    private optionsWasChanged(options: IWebI18nOptions) {
        return  this.webOptions.context !== options.context
            || this.webOptions.url !== options.url
            || this.webOptions.language !== options.language;
    }

    /**
     * Método responsável por carregar as literais do contexto do THF
     */
    private updateLiteralsFromThfContext(): Observable<ILiterals> {
        return this.thfI18nService.getLiterals({
            context: this.webOptions.context,
            language: this.webOptions.language
        }).pipe( map((res: ILiterals) => res) );
    }

}

==> totvs-log-web-foundation-1.0.0.tgz: package/src/lib/services/intl/intl-literal-loader.service.ts <==
import { ILiteralsLoader } from 'totvs-log-base-foundation';
import { Observable } from 'rxjs';
import { map, mergeMap, catchError } from 'rxjs/operators';
import { ILiterals } from 'totvs-log-base-foundation';
import { HttpClient } from '@angular/common/http';
import { IWebI18nOptions } from './web-i18n-options.interface';
import { Injectable } from '@angular/core';
import { PoI18nService } from '@portinari/portinari-ui';

/**
 * Serviço que realiza o carregamento das literais do serviço de internacionalização
 */
@Injectable()
export class IntlLiteralsLoaderService implements ILiteralsLoader {

    /**
     * Atributo com opções de internacionalização Web
     */
    private webOptions: IWebI18nOptions = {context: '', language: '', url: ''};
    /**
     * Representa o cache da informação, em memória
     */
    private cache: any;

    /**
     * Método construtor da classe
     * @param http Parâmetro do serviço de Http
     * @param poI18nService Parâmetro do serviço de internacionalização do Po
     */
    constructor(private http: HttpClient,
                private poI18nService: PoI18nService) {

    }

    /**
     * Método responsável por alterar as opções para carregamento de literais
     * @param options Parâmetro com as opções de internacionalização (url, language, context)
     */
    updateOptions(options: IWebI18nOptions): Observable<ILiterals> {
        const obs = new Observable<ILiterals>((observer) => {
            if ( this.optionsWasChanged(options) ) {
                Object.assign(this.webOptions, options);
                this.load().subscribe(x => {
                    this.cache = x;
                    observer.next(this.cache);
                });
            } else if (this.cache) {
                observer.next(this.cache);
            }
        });
        return obs;

    }


    /**
     * Método responsável por realizar o carregamento inicial das literais
     */
    load(): Observable<ILiterals> {
        return this.http.get<ILiterals>(this.webOptions.url)
        .pipe( map((res: ILiterals) => {
            const s = this.poI18nService as any;
            s.config.contexts[this.webOptions.context] = res;
            s.setVarI18n(s.config.contexts);
            return res;
            }),
            mergeMap( (res) => this.updateLiteralsFromPoContext() ),
            catchError((e, caught) => caught)
        );

    }

    /**
     * Detecta se ocorreram mudanças na configuração
     */
    private optionsWasChanged(options: IWebI18nOptions) {
        return  this.webOptions.context !== options.context
            || this.webOptions.url !== options.url
            || this.webOptions.language !== options.language;
    }

    /**
     * Método responsável por carregar as literais do contexto do Po
     */
    private updateLiteralsFromPoContext(): Observable<ILiterals> {
        return this.poI18nService.getLiterals({
            context: this.webOptions.context,
            language: this.webOptions.language
        }).pipe( map((res: ILiterals) => res) );
    }

}
